
Changelog
=========

1.0.1 (2016-01-23)
------------------

* Fixed breakage on Python 3. Contributed by Chris Warrick in `#1 <https://github.com/ionelmc/python-ghp-import/pull/1>`_.

1.0.0 (2015-05-09)
------------------

* First release on PyPI.
